# st-cockroachdb-connection

![Streamlit](https://img.shields.io/badge/Streamlit-FF4B4B?style=for-the-badge&logo=Streamlit&logoColor=white)
![CockroachDB](https://img.shields.io/badge/CockroachDB-6933FF?style=for-the-badge&logo=Cockroach%20Labs&logoColor=white)
![LICENSE](https://img.shields.io/github/license/putuwaw/st-cockroachdb-connection?style=for-the-badge)
![BUILD](https://img.shields.io/github/actions/workflow/status/putuwaw/st-cockroachdb-connection/ci.yml?style=for-the-badge)
![PyPI - Version](https://img.shields.io/pypi/v/st-cockroachdb-connection?style=for-the-badge)
![PyPI - Downloads](https://img.shields.io/pypi/dm/st-cockroachdb-connection?style=for-the-badge)

Streamlit Connection for CockroachDB.

## Features 🚀

With this apps you can connect to CockroachDB easily using `st.connection` in just few lines of code. You can also execute SQL queries and see the result in more efficient way.

## Prerequisites 📋

- Python 3.8 or higher
- Streamlit 1.28.0 or higher
- Psycopg 3.0 or higher

## Installation 🛠

```bash
pip install st-cockroachdb-connection
```

## Usage 📖

You can see the example app on [examples](examples) folder.

## License 📝

This project is licensed under the MIT License. See the [LICENSE](LICENSE) file for details.
